<template>
  <!-- 备品件添加 -->
  <div>
    <el-dialog :title="title + '车辆信息'" :visible.sync="showFormDia" width="80%" :before-close="handleClose"
      custom-class="bbsl-location-dialog" top="8vh">
      <div class="bbsl-scroll-pane">
        <el-form ref="formInfo" class="bbsl-scroll-form-spare" :rules="rules" :model="params" label-width="150px">
          <p id="step1" class="from-title">
            <i class="el-icon-info" />
            <span>基本信息</span>
          </p>
          <el-row>
            <el-col :span="8">
              <el-form-item label="车牌号码：" prop="code">
                <el-input v-model="params.code" maxlength="10" placeholder="请输入车牌号码" show-word-limit />
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="标识名称：">
                <el-input v-model="params.name" placeholder="请输入标识名称" maxlength="20" show-word-limit />
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="车辆类型：" prop="vehicleType">
                <!-- <el-input
			      size="small"
			      placeholder="请输入车辆类型"
			      v-model="params.vehicleType"
			      maxlength="18"
			    ></el-input> -->
                <el-select v-model="params.vehicleType" clearable style="width:100%" placeholder="请选择燃油类型">
                  <el-option v-for="item in vehicleTypes" :key="item.value" :label="item.name" :value="item.value" />
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="8">
              <el-form-item label="车辆品牌：" prop="brand">
                <el-input v-model="params.brand" maxlength="50" placeholder="请输入车辆品牌" />
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="车辆颜色：" prop="color">
                <el-input v-model="params.color" maxlength="20" placeholder="请输入车辆颜色" show-word-limit />
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="燃油类型：" prop="fuelType">
                <el-select v-model="params.fuelType" clearable style="width:100%" placeholder="请选择燃油类型">
                  <el-option v-for="item in fuelTypes" :key="item.value" :label="item.name" :value="item.value" />
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="8">
              <el-form-item label="购买日期：" prop="purchaseDate">
                <el-date-picker v-model="params.purchaseDate" type="date" value-format="yyyy-MM-dd"
                  placeholder="请选择购买日期" style="width:100%" />
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="用途：" prop="description">
                <el-input v-model="params.description" maxlength="30" placeholder="请输入用途" show-word-limit />
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="车辆使用性质：" prop="function">
                <el-select v-model="params.function" clearable style="width:100%" placeholder="请选择车辆使用性质">
                  <el-option v-for="item in vehicleNatures" :key="item.value" :label="item.name" :value="item.value" />
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
          <el-form-item label="备注" prop="memo">
            <el-input v-model="params.memo" type="textarea" maxlength="500" show-word-limit
              :autosize="{ minRows: 3, maxRows: 4 }" placeholder="请输入备注内容" />
          </el-form-item>
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import VehicleManage from '@/api/manager/duty/vehicleManage.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'VehicleManageDiglog',
  components: {},
  props: {},
  data() {
    return {
      title: '新增',
      showFormDia: false,
      fuelTypes: [],
      vehicleTypes: [],
      vehicleNatures: [],
      params: {
        code: '',
        name: '',
        memo: '',
        id: null,
        purchaseDate: '',
        fuelType: '',
        description: '',
        color: '',
        brand: '',
        vehicleType: '',
        function:'',
        pkVal: '',
        sn: 0,
        version: 0
      },
      rules: {
        code: [
          {
            required: true,
            message: '请输入车牌号码',
            trigger: 'blur'
          }
        ],
        name: [
          {
            required: true,
            message: '请输入标识名称',
            trigger: 'blur'
          }
        ],
        purchaseDate: [
          {
            required: true,
            message: '请选择购买日期',
            trigger: 'blur'
          }
        ],
        function: [
        {
            required: true,
            message: '请选择车辆使用性质',
            trigger: 'change'
          }
        ]
      }
    }
  },
  created() {
    console.log('----------created-----------')
    this.fuelTypes = dictContracts.getDictItemsFromCache('cmgt_rylx')
    this.vehicleTypes = dictContracts.getDictItemsFromCache('cmgt_cllx')
    this.vehicleNatures = dictContracts.getDictItemsFromCache('clsyxz')
  },
  methods: {
    add() {
      this.showFormDia = true
    },
    handleClose() {
      this.params = {
        code: '',
        name: '',
        memo: '',
        purchaseDate: '',
        fuelType: '',
        description: '',
        color: '',
        brand: '',
        vehicleType: '',
        function: ''
      }
      this.title = '新增'
      this.showFormDia = false
    },
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          let method
          if (!this.params.id) {
            // 新增
            method = VehicleManage.addVehicle
          }
          if (this.params.id) {
            // 修改
            method = VehicleManage.editVehicle
          }
          method(this.params, res => {
            if (res.state) {
              this.$notify({
                type: 'success',
                message: this.title + '成功',
                duration: 2000
              })
              // this.$emit('loadData')
              this.$parent.loadData()
              this.handleClose()
            } else {
              this.$message.warning(response.message)
            }
          })
        }
      })
    },
    Update(row) {
      console.log(row)
      this.title = '修改'
      this.showFormDia = true
      this.params.memo = row.memo
      this.params.name = row.name
      this.params.code = row.code
      this.params.id = row.id
      this.params.purchaseDate = row.purchaseDate
      this.params.fuelType = row.fuelType
      this.params.description = row.description
      this.params.color = row.color
      this.params.brand = row.brand
      this.params.vehicleType = row.vehicleType 
      this.params.function = row.function
    }
  }
}
</script>
<style lang="scss" scoped>
.redBull {
  border: 1px solid red;
}

.bbsl-scroll-form-spare {
  width: calc(100% - 20px);
  height: calc(95vh - 500px);
  overflow-y: auto;
  padding: 0 10px;
}
</style>
